@@ -4,6 +4,8 @@ options(digits=12)
 if(!require("frailtypack"))stop("this test requires package frailtypack.")
 if(!require("survival"))stop("this test requires survival.")
 if(!require("boot"))stop("this test requires boot.")
+if(!require("MASS"))stop("this test requires MASS.")
+if(!require("survC1"))stop("this test requires survC1.")
 
 cat("frailtypack test for shared model ...\n")
 
