@@ -9,31 +9,31 @@
          integer,intent(in) :: m,effet
          integer,intent(inout)::ni,ier,istop
          double precision,dimension(m*(m+3)/2),intent(out)::v
-	 double precision,dimension(2)::k0
+     double precision,dimension(2)::k0
          double precision,intent(out)::rl
-         double precision,dimension(m),intent(inout)::b	
-	 double precision,intent(out)::ca,cb,dd
-	 external::fctnames
-	 double precision::fctnames
+         double precision,dimension(m),intent(inout)::b    
+     double precision,intent(out)::ca,cb,dd
+     external::fctnames
+     double precision::fctnames
 
       end subroutine marq98j
 
       subroutine derivaj(b,m,v,rl,k0,fctnames)
         integer,intent(in)::m
-	double precision,dimension(2)::k0
+    double precision,dimension(2)::k0
         double precision,intent(inout)::rl
         double precision,dimension(m),intent(in)::b
         double precision,dimension((m*(m+3)/2)),intent(out)::v
-	double precision,external::fctnames
+    double precision,external::fctnames
       end subroutine derivaj
 
       subroutine searpasj(vw,step,b,bh,m,delta,fim,k0,fctnames)
         integer,intent(in)::m
-	double precision,dimension(2)::k0
+    double precision,dimension(2)::k0
         double precision,dimension(m),intent(in)::b
         double precision,dimension(m),intent(inout)::bh,delta
         double precision,intent(inout)::vw,fim,step
-	double precision,external::fctnames
+    double precision,external::fctnames
       end subroutine searpasj
 
       subroutine dmfsdj(a,n,eps,ier)
@@ -45,12 +45,12 @@
 
       subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames)
         integer,intent(in)::m
-	double precision,dimension(2)::k0
-	double precision,intent(in)::vw
+    double precision,dimension(2)::k0
+    double precision,intent(in)::vw
         double precision,dimension(m),intent(in)::b,delta
         double precision,dimension(m),intent(out)::bk
         double precision,intent(out)::fi
-	double precision,external::fctnames
+    double precision,external::fctnames
       end subroutine valfpaj
 
       subroutine dmaxt(maxt,delta,m)
@@ -101,7 +101,7 @@
 !-------------------------------------------------------------
 
 
-	subroutine marq98j(k0,b,m,ni,v,rl,ier,istop,effet,ca,cb,dd,fctnames)
+    subroutine marq98j(k0,b,m,ni,v,rl,ier,istop,effet,ca,cb,dd,fctnames)
 
 !
 !  fu = matrice des derivees secondes et premieres
@@ -110,333 +110,333 @@
 !  1: critere d'arret satisfait (prm=ca, vraisblce=cb, derivee=dd)
 !  2: nb max d'iterations atteints
 !  4: Erreur
-	use residusM,only:indg
-	use parameters
-	use comon,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
-	nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
-	PEN_deri,I_hess,H_hess,Hspl_hess,hess,indic_ALPHA,typeof,indic_eta,vvv
+    use residusM,only:indg
+    use parameters
+    use comon,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
+    nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
+    PEN_deri,I_hess,H_hess,Hspl_hess,hess,indic_ALPHA,typeof,indic_eta,vvv
 
 !add additive
-	use additiv,only:correl
+    use additiv,only:correl
 
-	IMPLICIT NONE
+    IMPLICIT NONE
 !   variables globales
-	integer,intent(in) :: m,effet
-	integer,intent(inout)::ni,ier,istop
-	double precision,dimension(m*(m+3)/2),intent(out)::v
-	double precision,intent(out)::rl
-	double precision,dimension(m),intent(inout)::b
-	double precision,intent(out)::ca,cb,dd
-	double precision,dimension(2)::k0
+    integer,intent(in) :: m,effet
+    integer,intent(inout)::ni,ier,istop
+    double precision,dimension(m*(m+3)/2),intent(out)::v
+    double precision,intent(out)::rl
+    double precision,dimension(m),intent(inout)::b
+    double precision,intent(out)::ca,cb,dd
+    double precision,dimension(2)::k0
         double precision,dimension(2)::zero
 !   variables locales
-	integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
-	double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
-	double precision,dimension(m)::delta,b1,bh
-	double precision::da,dm,ga,tr
-	double precision::GHG,step,eps,vw,fi,maxt, &
-	z,rl1,th,ep
-	external::fctnames
-	double precision::fctnames
+    integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
+    double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
+    double precision,dimension(m)::delta,b1,bh
+    double precision::da,dm,ga,tr
+    double precision::GHG,step,eps,vw,fi,maxt, &
+    z,rl1,th,ep
+    external::fctnames
+    double precision::fctnames
 !---------- ajout
-	integer::kkk
+    integer::kkk
 
-	zero=0.d0
-	id=0
-	jd=0
-	z=0.d0
-	th=1.d-5
-	eps=1.d-7!1.d-6
-	nfmax=m*(m+1)/2
-	ca=epsa+1.d0
-	cb=epsb+1.d0
-	rl1=-1.d+10
-	ni=0
-	istop=0
-	da=0.01d0
-	dm=5.d0
-	nql=1
-	m1=m*(m+1)/2
-	ep=1.d-20
-	Main:Do
+    zero=0.d0
+    id=0
+    jd=0
+    z=0.d0
+    th=1.d-5
+    eps=1.d-7!1.d-6
+    nfmax=m*(m+1)/2
+    ca=epsa+1.d0
+    cb=epsb+1.d0
+    rl1=-1.d+10
+    ni=0
+    istop=0
+    da=0.01d0
+    dm=5.d0
+    nql=1
+    m1=m*(m+1)/2
+    ep=1.d-20
+    Main:Do
 
         call derivaj(b,m,v,rl,k0,fctnames)
 
-	rl1=rl
-	if(rl.eq.-1.D9) then
-		istop=4
-		goto 110
-	end if
+    rl1=rl
+    if(rl.eq.-1.D9) then
+        istop=4
+        goto 110
+    end if
 
-!	write(*,*)'iteration***',ni,'vrais',rl
+!    write(*,*)'iteration***',ni,'vrais',rl
 
         dd = 0.d0
 
         fu=0.D0
-	
-	do i=1,m
-		do j=i,m
-			ij=(j-1)*j/2+i
-			fu(ij)=v(ij)
-		end do
-	end do
-	
+    
+    do i=1,m
+        do j=i,m
+            ij=(j-1)*j/2+i
+            fu(ij)=v(ij)
+        end do
+    end do
+    
         call dsinvj(fu,m,ep,ier)
-	
-	if (ier.eq.-1) then ! hessienne non inversible
-		!print*,"here"
-		dd=epsd+1.d0
-	else
-		GHG = 0.d0
-		do i=1,m
-			do j=1,m
-				if(j.ge.i) then
-					ij=(j-1)*j/2+i
-				else
-					ij=(i-1)*i/2+j
-				end if
-				GHG = GHG + v(m1+i)*fu(ij)*V(m1+j)
-			end do
-		end do
-		dd=GHG/dble(m)
-	end if
+    
+    if (ier.eq.-1) then ! hessienne non inversible
+        !print*,"here"
+        dd=epsd+1.d0
+    else
+        GHG = 0.d0
+        do i=1,m
+            do j=1,m
+                if(j.ge.i) then
+                    ij=(j-1)*j/2+i
+                else
+                    ij=(i-1)*i/2+j
+                end if
+                GHG = GHG + v(m1+i)*fu(ij)*V(m1+j)
+            end do
+        end do
+        dd=GHG/dble(m)
+    end if
 
-!	print*,ca,cb,dd
-!	print*,b
-!	print*,"-------------------------"
-!	if (ni.eq.50) then
-!		print*,"====================> FAUSSE CONVERGENCE"
-!		ca=1.d-4
-!		cb=1.d-4
-!		dd=1.d-4
-!	endif
+!    print*,ca,cb,dd
+!    print*,b
+!    print*,"-------------------------"
+!     if (ni.eq.50) then
+!         print*,"====================> FAUSSE CONVERGENCE"
+!         ca=1.d-5
+!         cb=1.d-5
+!         dd=1.d-5
+!     endif
 
-	if(ca.lt.epsa.and.cb.lt.epsb.and.dd.lt.epsd) exit main
+    if(ca.lt.epsa.and.cb.lt.epsb.and.dd.lt.epsd) exit main
 
-		tr=0.d0
-		do i=1,m
-			ii=i*(i+1)/2
-			tr=tr+dabs(v(ii))
-		end do
-		tr=tr/dble(m)
-		
-		ncount=0
-		ga=0.01d0
+        tr=0.d0
+        do i=1,m
+            ii=i*(i+1)/2
+            tr=tr+dabs(v(ii))
+        end do
+        tr=tr/dble(m)
+        
+        ncount=0
+        ga=0.01d0
 
  400    do i=1,nfmax+m
            fu(i)=v(i)
         end do
 
-		do i=1,m
-			ii=i*(i+1)/2
-			if (v(ii).ne.0) then
-				fu(ii)=v(ii)+da*((1.d0-ga)*dabs(v(ii))+ga*tr)
-			else
-				fu(ii)=da*ga*tr
-			endif
-		end do
-		
-		call dcholej(fu,m,nql,idpos)
+        do i=1,m
+            ii=i*(i+1)/2
+            if (v(ii).ne.0) then
+                fu(ii)=v(ii)+da*((1.d0-ga)*dabs(v(ii))+ga*tr)
+            else
+                fu(ii)=da*ga*tr
+            endif
+        end do
+        
+        call dcholej(fu,m,nql,idpos)
 
-		if (idpos.ne.0) then
-			ncount=ncount+1
-			if (ncount.le.3.or.ga.ge.1.d0) then
-				da=da*dm
-			else
-				ga=ga*dm
-				if (ga.gt.1.d0) ga=1.d0
-			endif
+        if (idpos.ne.0) then
+            ncount=ncount+1
+            if (ncount.le.3.or.ga.ge.1.d0) then
+                da=da*dm
+            else
+                ga=ga*dm
+                if (ga.gt.1.d0) ga=1.d0
+            endif
 
-			goto 400
+            goto 400
 
-		else
-			do i=1,m
-				delta(i)=fu(nfmax+i)
-				b1(i)=b(i)+delta(i)
-			end do
-			
-			rl=fctnames(b1,m,id,z,jd,z,k0)
-			if(rl.eq.-1.D9) then
-				istop=4
-				goto 110
-			end if
-			if (rl1.lt.rl) then
-				if(da.lt.eps) then
-					da=eps
-				else
-					da=da/(dm+2.d0)
-				endif
-				goto 800
-			endif
-		endif
+        else
+            do i=1,m
+                delta(i)=fu(nfmax+i)
+                b1(i)=b(i)+delta(i)
+            end do
+            
+            rl=fctnames(b1,m,id,z,jd,z,k0)
+            if(rl.eq.-1.D9) then
+                istop=4
+                goto 110
+            end if
+            if (rl1.lt.rl) then
+                if(da.lt.eps) then
+                    da=eps
+                else
+                    da=da/(dm+2.d0)
+                endif
+                goto 800
+            endif
+        endif
 !      write(6,*) 'loglikelihood not improved '
-		call dmaxt(maxt,delta,m)
+        call dmaxt(maxt,delta,m)
 
-		if(maxt.eq.0.D0) then
-			vw=th
-		else
-			!call dmaxt(maxt,delta,m)
-			vw=th/maxt
-			
-		endif
-		step=dlog(1.5d0)
+        if(maxt.eq.0.D0) then
+            vw=th
+        else
+            !call dmaxt(maxt,delta,m)
+            vw=th/maxt
+            
+        endif
+        step=dlog(1.5d0)
 !      write(*,*) 'searpas'
-		call searpasj(vw,step,b,bh,m,delta,fi,k0,fctnames)
-		rl=-fi
-		if(rl.eq.-1.D9) then
-			istop=4
-			goto 110
-		end if
+        call searpasj(vw,step,b,bh,m,delta,fi,k0,fctnames)
+        rl=-fi
+        if(rl.eq.-1.D9) then
+            istop=4
+            goto 110
+        end if
 
-		do i=1,m
-			delta(i)=vw*delta(i)
-		end do
-		da=(dm-3.d0)*da
+        do i=1,m
+            delta(i)=vw*delta(i)
+        end do
+        da=(dm-3.d0)*da
 
  800     cb=dabs(rl1-rl)
  
-		ca=0.d0
-		do i=1,m
-			ca=ca+delta(i)*delta(i)
-		end do
+        ca=0.d0
+        do i=1,m
+            ca=ca+delta(i)*delta(i)
+        end do
         !write(6,*) 'ca =',ca,' cb =',cb,' dd =',dd
 
-		do i=1,m
-			b(i)=b(i)+delta(i)
-		end do
-	
-		ni=ni+1
-		if (ni.ge.maxiter) then
-			istop=2
+        do i=1,m
+            b(i)=b(i)+delta(i)
+        end do
+        
+        ni=ni+1
+        if (ni.ge.maxiter) then
+            istop=2
 !            write(6,*) 'maximum number of iteration reached'
-			goto 110
-		end if
-	End do Main
+            goto 110
+        end if
+    End do Main
 
-	v=0.D0
-	
-	v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
-	
-	istop=1
-	
+    v=0.D0
+    
+    v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
+    
+    istop=1
+    
 !================ pour les bandes de confiance
 !==== on ne retient que les para des splines
 
-	call derivaJ(b,m,v,rl,k0,fctnames)
-	if(rl.eq.-1.D9) then
-		istop=4
-		goto 110
-	end if
+    call derivaJ(b,m,v,rl,k0,fctnames)
+    if(rl.eq.-1.D9) then
+        istop=4
+        goto 110
+    end if
 
-	do i=1,(m*(m+3)/2)
-		v1(i)=0.d0
-	end do
+    do i=1,(m*(m+3)/2)
+        v1(i)=0.d0
+    end do
 !---- Choix du model
 
-	select case(model)
-		case(1)
-			m1=m-nva-effet-indic_alpha !joint
-		case(2)
-			m1=m-nva-effet*2 !additive	
-		case(3)
-			m1=m-nva-effet !nested
-		case(4)
-			m1=m-nva-effet !shared
-	end select
+    select case(model)
+        case(1)
+            m1=m-nva-effet-indic_alpha !joint
+        case(2)
+            m1=m-nva-effet*2 !additive    
+        case(3)
+            m1=m-nva-effet !nested
+        case(4)
+            m1=m-nva-effet !shared
+    end select
 
-	kkk=m1*(m1+1)/2
-	
-	do i=1,m1
-		kkk=kkk+1
-		do j=i,m1
-			k = (((j-1)*j)/2) +i
-			v1(k)=v(k)/(4.d0*b(i)*b(j))
-		end do
-		v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
-	end do 
+    kkk=m1*(m1+1)/2
+    
+    do i=1,m1
+        kkk=kkk+1
+        do j=i,m1
+            k = (((j-1)*j)/2) +i
+            v1(k)=v(k)/(4.d0*b(i)*b(j))
+        end do
+        v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
+    end do 
 
-	ep=10.d-10
-	call dsinvJ(v1,m1,ep,ier)
+    ep=10.d-10
+    call dsinvJ(v1,m1,ep,ier)
 
-	if (ier.eq.-1) then
+    if (ier.eq.-1) then
 !         write(*,*)   'echec inversion matrice information'
-		istop=3
-	endif
+        istop=3
+    endif
 
 
 
-	do i=1,m1
-		do j=i,m1
-			hess(i,j)=v1((j-1)*j/2+i)
-		end do
-	end do
+    do i=1,m1
+        do j=i,m1
+            hess(i,j)=v1((j-1)*j/2+i)
+        end do
+    end do
 
-	do i=2,m1
-		do j=1,i-1
-			hess(i,j)=hess(j,i)
-		end do
-	end do
+    do i=2,m1
+        do j=1,i-1
+            hess(i,j)=hess(j,i)
+        end do
+    end do
 
-	
-	ep=10.d-10
-	call dsinvJ(v,m,ep,ier)
-	
-	if (ier.eq.-1) then
-		istop=3
-		
+    
+    ep=10.d-10
+    call dsinvJ(v,m,ep,ier)
+    
+    if (ier.eq.-1) then
+        istop=3
+        
 !AD:
-!		call dsinvj(v1,m1,ep,ier)
-!		if (ier.eq.-1) then
+!        call dsinvj(v1,m1,ep,ier)
+!        if (ier.eq.-1) then
 !             write(*,*)'echec inversion matrice information
 !     & prms fixes'
-!			istop=31
-!		else
-!			DO k=1,m1*(m1+1)/2
-!				v(k)=v1(k)
-!			END DO
-!		end if	
+!            istop=31
+!        else
+!            DO k=1,m1*(m1+1)/2
+!                v(k)=v1(k)
+!            END DO
+!        end if    
 ! fin ajout amadou
-	endif
+    endif
 
 
-	ep=10.d-10
-	call derivaJ(b,m,vnonpen,rl,zero,fctnames)
-	
-	do i=1,m
-		do j=i,m
-			I_hess(i,j)=vnonpen((j-1)*j/2+i)
-		end do
-	end do
+    ep=10.d-10
+    call derivaJ(b,m,vnonpen,rl,zero,fctnames)
+    
+    do i=1,m
+        do j=i,m
+            I_hess(i,j)=vnonpen((j-1)*j/2+i)
+        end do
+    end do
    
-	do i=2,m
-		do j=1,i-1
-			I_hess(i,j)=I_hess(j,i)
-		end do
-	end do
+    do i=2,m
+        do j=1,i-1
+            I_hess(i,j)=I_hess(j,i)
+        end do
+    end do
 
 !========================================================
 
 !   H_hess est moins la hessienne inverse sur la vraisemblance penalisee
-	do i=1,m
-		do j=i,m
-			H_hess(i,j)=v((j-1)*j/2+i)
-		end do
-	end do
+    do i=1,m
+        do j=i,m
+            H_hess(i,j)=v((j-1)*j/2+i)
+        end do
+    end do
 !       write(*,*) 'H_hess(16,16) fin marq',H_hess(16,16),m,((j-1)*j/2+i)
 
-	do i=2,m
-		do j=1,i-1
-			H_hess(i,j)=H_hess(j,i)
-		end do
-	end do      
+    do i=2,m
+        do j=1,i-1
+            H_hess(i,j)=H_hess(j,i)
+        end do
+    end do      
 
  !AD:
-	if (typeof .ne. 0) then
-		do i=1,m*(m+1)/2
-			vvv(i)=v(i)
-		end do
-	end if
-	   
+    if (typeof .ne. 0) then
+        do i=1,m*(m+1)/2
+            vvv(i)=v(i)
+        end do
+    end if
+       
  110   continue
 
        return    
@@ -446,75 +446,75 @@
 !                          DERIVA
 !------------------------------------------------------------
 
-	subroutine derivaj(b,m,v,rl,k0,fctnames)
-	use comon,only:model
-	implicit none
-	
-	integer,intent(in)::m
-	double precision,intent(inout)::rl
-	double precision,dimension(2)::k0
-	double precision,dimension(m),intent(in)::b
-	double precision,dimension((m*(m+3)/2)),intent(out)::v
-	double precision,dimension(m)::fcith
-	integer ::i0,m1,ll,i,k,j,iun
-	double precision::fctnames,thn,th,z,vl,th2,vaux
-	external::fctnames
+    subroutine derivaj(b,m,v,rl,k0,fctnames)
+    use comon,only:model
+    implicit none
+    
+    integer,intent(in)::m
+    double precision,intent(inout)::rl
+    double precision,dimension(2)::k0
+    double precision,dimension(m),intent(in)::b
+    double precision,dimension((m*(m+3)/2)),intent(out)::v
+    double precision,dimension(m)::fcith
+    integer ::i0,m1,ll,i,k,j,iun
+    double precision::fctnames,thn,th,z,vl,th2,vaux
+    external::fctnames
 
-	select case(model)
-	case(1)
-		th=1.d-3 !joint
-	case(2)
-		th=5.d-3 !additive
-	case(3)
-		th=1.d-5 !nested
-	case(4)
-		th=1.d-5 !shared
-	end select
+    select case(model)
+    case(1)
+        th=1.d-3 !joint
+    case(2)
+        th=5.d-3 !additive
+    case(3)
+        th=1.d-5 !nested
+    case(4)
+        th=1.d-5 !shared
+    end select
 
-	thn=-th
-	th2=th*th
-	z=0.d0
-	i0=0
-	iun =1
+    thn=-th
+    th2=th*th
+    z=0.d0
+    i0=0
+    iun =1
 
-	rl=fctnames(b,m,iun,z,iun,z,k0)
+    rl=fctnames(b,m,iun,z,iun,z,k0)
 
-	if(rl.eq.-1.d9) then
-		rl=-1.d9
-		goto 123
-	end if
+    if(rl.eq.-1.d9) then
+        rl=-1.d9
+        goto 123
+    end if
 
-	do i=1,m
-		fcith(i)=fctnames(b,m,i,th,i0,z,k0)
-		if(fcith(i).eq.-1.d9) then
-			rl=-1.d9
-			goto 123
-		end if
-	end do
+    do i=1,m
+        fcith(i)=fctnames(b,m,i,th,i0,z,k0)
+        if(fcith(i).eq.-1.d9) then
+            rl=-1.d9
+            goto 123
+        end if
+    end do
 
-	k=0
-	m1=m*(m+1)/2
-	ll=m1
-	
-	do i=1,m
-		ll=ll+1
-		vaux=fctnames(b,m,i,thn,i0,z,k0)
+    k=0
+    m1=m*(m+1)/2
+    ll=m1
+    
+    do i=1,m
+        ll=ll+1
+        vaux=fctnames(b,m,i,thn,i0,z,k0)
                 if(vaux.eq.-1.d9) then
                     rl=-1.d9
                     goto 123
-                end if	
-		vl=(fcith(i)-vaux)/(2.d0*th)
-		v(ll)=vl
-		do j=1,i
-			k=k+1
-			v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
-		end do
-	end do
+                end if    
+        vl=(fcith(i)-vaux)/(2.d0*th)
+        v(ll)=vl
+        do j=1,i
+            k=k+1
+            v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
+        end do
+    end do
 
-123   continue	
-	return
-	
-	end subroutine derivaj
+123   continue    
+    return
+    
+    end subroutine derivaj
 !------------------------------------------------------------
 !                        SEARPAS
 !------------------------------------------------------------
@@ -543,11 +543,11 @@
        call valfpaj(vlw2,fi2,b,bh,m,delta,k0,fctnames)
 
        if(fi2.ge.fi1) then
-	  vlw3=vlw2
-	  vlw2=vlw1
-	  fi3=fi2
-	  fi2=fi1
-	  step=-step
+      vlw3=vlw2
+      vlw2=vlw1
+      fi3=fi2
+      fi2=fi1
+      step=-step
 
           vlw1=vlw2+step
           call valfpaj(vlw1,fi1,b,bh,m,delta,k0,fctnames)
@@ -584,7 +584,7 @@
 !  CALCUL MINIMUM QUADRIQUE
 !
       vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
-      call valfpaj(vm,fim,b,bh,m,delta,k0,fctnames)	
+      call valfpaj(vm,fim,b,bh,m,delta,k0,fctnames)    
       if(fim.le.fi2) goto 100
       vm=vlw2
       fim=fi2
@@ -606,10 +606,10 @@
       integer,intent(in)::k,nq
       integer,intent(inout)::idpos
       double precision,dimension(k*(k+3)/2),intent(inout)::a
-		
+        
       integer::i,ii,i1,i2,i3,m,j,k2,jmk
       integer::ijm,irm,jji,jjj,l,jj,iil,jjl,il
-      integer,dimension(k)::is	
+      integer,dimension(k)::is    
       double precision ::term,xn,diag,p
       equivalence (term,xn)
       
@@ -644,7 +644,7 @@
              if(is(l).ge.0) goto 3
 2            p=-p
 3            diag=diag-p
-         end do	 
+         end do     
          
 4        if(diag.lt.0) goto 5
          if(diag.eq.0) goto 50
@@ -679,7 +679,7 @@
 12             term=term-p
             end do
 13            a(jj)=term/diag
-	   end do  
+       end do  
       end do   
       
 !       calcul des solutions
@@ -758,7 +758,7 @@
 !   START FACTORIZATION-LOOP OVER K-TH ROW
 !
          do i=k,n
-	    dsum=0.d0
+        dsum=0.d0
             if (lend.lt.0) goto 2
             if (lend.eq.0) goto 4
             if (lend.gt.0) goto 2
@@ -768,20 +768,20 @@
 2           do l=1,lend
                lanf=kpiv-l
                lind=ind-l
-	       dsum=dsum+A(lanf)*A(lind)
+           dsum=dsum+A(lanf)*A(lind)
             end do 
-	      
+          
 !     
 !   END OF INNEF LOOP
 !
 !   TRANSFORM ELEMENT A(IND)
-! 	
+!     
 4           dsum=A(ind)-dsum
             if (i-k.ne.0) goto 10
             if (i-k.eq.0) goto 5
 !
 !   TEST FOR NEGATIVE PIVOT ELEMENT AND FOR LOSS OF SIGNIFICANCE
-!	
+!    
 5           if (sngl(dsum)-tol.le.0) goto 6
             if (sngl(dsum)-tol.gt.0) goto 9
 6           if (dsum.le.0) goto 12  
@@ -819,7 +819,7 @@
 !------------------------------------------------------------
 
 
-	subroutine dsinvj(A,N,EPS,IER)
+    subroutine dsinvj(A,N,EPS,IER)
 
 !
 !     INVERSION D'UNE MATRICE SYMETRIQUE DEFINIE POSITIVE :
@@ -840,25 +840,25 @@
 !         IER=-1 ERREUR SUR LA DIM.N OU MATRICE PAS DEFINIE POSITIVE
 !         IER=1 PERTE DE SIGNIFICANCE, LE CALCUL CONTINUE
 !
-	implicit none
-	
-	integer,intent(in)::n
-	integer,intent(inout)::ier
-	double precision,intent(inout)::eps        
-	double precision,dimension(n*(n+1)/2),intent(inout)::A     
-	double precision::din,work
-	integer::ind,ipiv,i,j,k,l,min,kend,lhor,lver,lanf
+    implicit none
+    
+    integer,intent(in)::n
+    integer,intent(inout)::ier
+    double precision,intent(inout)::eps        
+    double precision,dimension(n*(n+1)/2),intent(inout)::A     
+    double precision::din,work
+    integer::ind,ipiv,i,j,k,l,min,kend,lhor,lver,lanf
     
 !
 !     FACTORIZE GIVEN MATRIX BY MEANS OF SUBROUTINE DMFSD
 !     A=TRANSPOSE(T) * T
 !
 
-	call dmfsdj(A,n,eps,ier)
+    call dmfsdj(A,n,eps,ier)
       
 
 
-	if (ier.lt.0) goto 9
+    if (ier.lt.0) goto 9
 !      if (ier.ge.0) det=0.d0
 !
 !     INVERT UPPER TRIANGULAR MATRIX T
@@ -871,48 +871,48 @@
 !         det=det+dlog(A(i*(i+1)/2))
 !      end do
 !      det=2*det
-	ipiv=n*(n+1)/2
-	ind=ipiv
+    ipiv=n*(n+1)/2
+    ind=ipiv
 !
 !     INITIALIZE INVERSION-LOOP
 !
-	do i=1,n
-		din=1.d0/A(ipiv)
-		A(ipiv)=din
-		min=n
-		kend=i-1
-		lanf=n-kend
-		if (kend.le.0) goto 5
-		if (kend.gt.0) j=ind
-	!
+    do i=1,n
+        din=1.d0/A(ipiv)
+        A(ipiv)=din
+        min=n
+        kend=i-1
+        lanf=n-kend
+        if (kend.le.0) goto 5
+        if (kend.gt.0) j=ind
+    !
 !     INITIALIZE ROW-LOOP
 !
-		do k=1,kend
-			work=0.d0
-			min=min-1
-			lhor=ipiv
-			lver=j
+        do k=1,kend
+            work=0.d0
+            min=min-1
+            lhor=ipiv
+            lver=j
 !
 !     START INNER LOOP
 !
-			do l=lanf,min 
-				lver=lver+1
-				lhor=lhor+l
-				work=work+A(lver)*A(lhor)
-			end do	    
+            do l=lanf,min 
+                lver=lver+1
+                lhor=lhor+l
+                work=work+A(lver)*A(lhor)
+            end do        
 !
 !     END OF INNER LOOP
 !
-			A(j)=-work*din
-			j=j-min
-		end do
-	 
+            A(j)=-work*din
+            j=j-min
+        end do
+     
 !
 !     END OF ROW-LOOP
 !
 5        ipiv=ipiv-min 
-		ind=ind-1
-	end do
+        ind=ind-1
+    end do
       
 !
 !     END OF INVERSION-LOOP
@@ -921,30 +921,30 @@
 !     INVERSE(A) = INVERSE(T) * TRANSPOSE(INVERSE(T))
 !     INITIALIZE MULTIPLICATION-LOOP
 !
-	do i=1,n
-		ipiv=ipiv+i
-		j=ipiv
+    do i=1,n
+        ipiv=ipiv+i
+        j=ipiv
 !
 !     INITIALIZE ROW-LOOP
 !
-		do k=i,n
-			work=0.d0
-			lhor=j
+        do k=i,n
+            work=0.d0
+            lhor=j
 !
 !     START INNER LOOP
 !
-			do l=k,n
-				lver=lhor+k-i
-				work=work+A(lhor)*A(lver)
-				lhor=lhor+l
-			end do	    
+            do l=k,n
+                lver=lhor+k-i
+                work=work+A(lhor)*A(lver)
+                lhor=lhor+l
+            end do        
 !
 !     END OF INNER LOOP
 !       
-			A(j)=work
-			j=j+k
-		end do
-	end do
+            A(j)=work
+            j=j+k
+        end do
+    end do
       
 !
 !     END OF ROW-AND MULTIPLICATION-LOOP
@@ -956,566 +956,62 @@
 !                          VALFPA
 !------------------------------------------------------------
 
-	subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames)
-	
-	implicit none
-	
-	integer,intent(in)::m  
-	double precision,dimension(m),intent(in)::b,delta  
-	double precision,dimension(m),intent(out)::bk 
-	double precision,intent(out)::fi 
-	double precision::vw,fctnames,z	
-	double precision,dimension(2)::k0
-	integer::i0,i
-	external::fctnames
-	
-	z=0.d0
-	i0=1
-	do i=1,m
-	bk(i)=b(i)+dexp(vw)*delta(i)
-	end do
-	fi=-fctnames(bk,m,i0,z,i0,z,k0)
-	if(fi.eq.-1.D9) then
-		goto 1
-	end if
+    subroutine valfpaj(vw,fi,b,bk,m,delta,k0,fctnames)
+    
+    implicit none
+    
+    integer,intent(in)::m  
+    double precision,dimension(m),intent(in)::b,delta  
+    double precision,dimension(m),intent(out)::bk 
+    double precision,intent(out)::fi 
+    double precision::vw,fctnames,z    
+    double precision,dimension(2)::k0
+    integer::i0,i
+    external::fctnames
+    
+    z=0.d0
+    i0=1
+    do i=1,m
+    bk(i)=b(i)+dexp(vw)*delta(i)
+    end do
+    fi=-fctnames(bk,m,i0,z,i0,z,k0)
+    if(fi.eq.-1.D9) then
+        goto 1
+    end if
 1       continue
-	return
-	
-	end subroutine valfpaj
+    return
+    
+    end subroutine valfpaj
 
 !------------------------------------------------------------
 !                            MAXT
 !------------------------------------------------------------
-	subroutine dmaxt(maxt,delta,m)
-	
-	implicit none
-	
-	integer,intent(in)::m
-	double precision,dimension(m),intent(in)::delta
-	double precision,intent(out)::maxt
-	integer::i 
-	
-	maxt=Dabs(delta(1))
+    subroutine dmaxt(maxt,delta,m)
+    
+    implicit none
+    
+    integer,intent(in)::m
+    double precision,dimension(m),intent(in)::delta
+    double precision,intent(out)::maxt
+    integer::i 
+    
+    maxt=Dabs(delta(1))
 
-	do i=2,m
-		if(Dabs(delta(i)).gt.maxt)then
-			maxt=Dabs(delta(i))
-		end if
+    do i=2,m
+        if(Dabs(delta(i)).gt.maxt)then
+            maxt=Dabs(delta(i))
+        end if
 
-	end do 
-		
-	return
-	end subroutine dmaxt
-
-!----------- add for multiv Yassin
-
-	subroutine marq98(k0,b,m,ni,v,rl,ier,istop,effet,ca,cb,dd,fctnames)
-
-!
-!  fu = matrice des derivees secondes et premieres
-!
-!  istop: raison de l'arret
-!  1: critere d'arret satisfait (prm=ca, vraisblce=cb, derivee=dd)
-!  2: nb max d'iterations atteints
-!  4: Erreur
-	use residusMmultiv,only:indg
-	use parametersmultiv
-	use comonmultiv,only:t0,t1,t0dc,t1dc,c,cdc,nt0,nt1,nt0dc, &
-	nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst,model, &
-	PEN_deri,I_hess,H_hess,Hspl_hess,hess,indic_ALPHA,typeof,indic_eta,vvv
-
-!add additive
-	use additiv,only:correl
-      
-	IMPLICIT NONE
-!   variables globales 
-	integer,intent(in) :: m,effet
-	integer,intent(inout)::ni,ier,istop
-	double precision,dimension(m*(m+3)/2),intent(out)::v
-	double precision,intent(out)::rl
-	double precision,dimension(m),intent(inout)::b
-	double precision,intent(out)::ca,cb,dd
-	double precision,dimension(3)::k0
-        double precision,dimension(3)::zero
-!   variables locales            
-	integer::nql,ii,nfmax,idpos,ncount,id,jd,m1,j,i,ij,k
-	double precision,dimension(m*(m+3)/2)::fu,v1,vnonpen
-	double precision,dimension(m)::delta,b1,bh
-	double precision::da,dm,ga,tr
-	double precision::GHG,step,eps,vw,fi,maxt, &
-	z,rl1,th,ep
-	external::fctnames
-	double precision::fctnames
-!---------- ajout
-	integer::kkk
-
-	zero=0.d0     
-	id=0
-	jd=0
-	z=0.d0
-	th=1.d-5
-	eps=1.d-7!1.d-6
-	nfmax=m*(m+1)/2  	  
-	ca=epsa+1.d0
-	cb=epsb+1.d0
-	rl1=-1.d+10    
-	ni=0
-	istop=0
-	da=0.01d0
-	dm=5.d0
-	nql=1
-	m1=m*(m+1)/2
-	ep=1.d-20
-	Main:Do 
-
-        call deriva(b,m,v,rl,k0,fctnames)   
-
-        rl1=rl
-	if(rl.eq.-1.D9) then
-		istop=4
-		goto 110
-	end if
-! 	write(*,*)'parameters***',b
-!	write(*,*)'Optim iteration***',ni,'vrais',rl  
-	   
-        dd = 0.d0    
-	 
-        fu=0.D0
-	
-	do i=1,m
-		do j=i,m
-			ij=(j-1)*j/2+i
-			fu(ij)=v(ij)
-		end do
-	end do
-	
-        call dsinvj(fu,m,ep,ier)  
-	
-	if (ier.eq.-1) then
-		dd=epsd+1.d0
-	else
-		GHG = 0.d0
-		do i=1,m
-			do j=1,m
-				if(j.ge.i) then
-					ij=(j-1)*j/2+i
-				else
-					ij=(i-1)*i/2+j
-				end if
-				GHG = GHG + v(m1+i)*fu(ij)*V(m1+j)
-			end do
-		end do
-		dd=GHG/dble(m)
-	end if
-	if(ca.lt.epsa.and.cb.lt.epsb.and.dd.lt.epsd) exit main
-
-		tr=0.d0
-		do i=1,m
-			ii=i*(i+1)/2
-			tr=tr+dabs(v(ii))
-		end do
-		tr=tr/dble(m)
-		
-		ncount=0
-		ga=0.01d0
-		
- 400    do i=1,nfmax+m
-           fu(i)=v(i)
-        end do
-	
-		do i=1,m
-			ii=i*(i+1)/2
-			if (v(ii).ne.0) then
-				fu(ii)=v(ii)+da*((1.d0-ga)*dabs(v(ii))+ga*tr)
-			else
-				fu(ii)=da*ga*tr
-			endif
-		end do
-		
-		call dcholej(fu,m,nql,idpos)
-		if (idpos.ne.0) then
-			ncount=ncount+1
-			if (ncount.le.3.or.ga.ge.1.d0) then
-				da=da*dm
-			else
-				ga=ga*dm
-				if (ga.gt.1.d0) ga=1.d0
-			endif
-	
-			goto 400
-
-		else
-			do i=1,m
-				delta(i)=fu(nfmax+i)
-				b1(i)=b(i)+delta(i)
-			end do
-			rl=fctnames(b1,m,id,z,jd,z,k0)
-			if(rl.eq.-1.D9) then
-				istop=4
-				goto 110
-			end if
-			if (rl1.lt.rl) then
-				if(da.lt.eps) then
-					da=eps
-				else
-					da=da/(dm+2.d0)
-				endif
-				goto 800
-			endif
-		endif
-!      write(6,*) 'loglikelihood not improved '
-		call dmaxt(maxt,delta,m)
-
-		if(maxt.eq.0.D0) then
-			vw=th
-		else
-			!call dmaxt(maxt,delta,m)
-			vw=th/maxt
-			
-		endif
-		step=dlog(1.5d0)
-!      write(*,*) 'searpas'
-		call searpas(vw,step,b,bh,m,delta,fi,k0,fctnames)
-		rl=-fi
-		if(rl.eq.-1.D9) then
-			istop=4
-			goto 110
-		end if
-            
-		do i=1,m
-			delta(i)=vw*delta(i)
-		end do
-		da=(dm-3.d0)*da
-
- 800     cb=dabs(rl1-rl)
-		ca=0.d0
-		do i=1,m
-			ca=ca+delta(i)*delta(i)
-		end do
-!         write(6,*) 'ca =',ca,' cb =',cb,' dd =',dd
-		do i=1,m
-			b(i)=b(i)+delta(i)
-		end do
-	
-		ni=ni+1
-
-		if (ni.ge.maxiter) then
-			istop=2
- !           write(6,*) 'maximum number of iteration reached'
-			goto 110
-		end if	 
-	End do Main
-
-	v=0.D0
-		
-	v(1:m*(m+1)/2)=fu(1:m*(m+1)/2)
-	
-	istop=1
-	
-!================ pour les bandes de confiance
-!==== on ne retient que les para des splines
-
-	call deriva(b,m,v,rl,k0,fctnames)
-	if(rl.eq.-1.D9) then
-		istop=4
-		goto 110
-	end if
-
-	do i=1,(m*(m+3)/2)
-		v1(i)=0.d0
-	end do
-!---- Choix du model
-
-	select case(model) 
-		case(1)  
-			m1=m-nva-effet-indic_alpha !joint
-		case(2)
-			m1=m-nva-effet*2 !additive	
-		case(3)
-			m1=m-nva-effet !nested
-		case(4)	
-			m1=m-nva-effet !shared
-	end select
-
-	kkk=m1*(m1+1)/2
-	
-	do i=1,m1
-		kkk=kkk+1
-		do j=i,m1
-			k = (((j-1)*j)/2) +i
-			v1(k)=v(k)/(4.d0*b(i)*b(j))
-		end do
-		v1(kkk)=v1(kkk)+(v(kkk)/(4.d0*b(i)*b(i)*b(i)))
-	end do 
-
-	ep=10.d-10
-	call dsinvJ(v1,m1,ep,ier)
-	
-	if (ier.eq.-1) then
-!         write(*,*)   'echec inversion matrice information'
-		istop=3
-	endif
-
-
-
-	do i=1,m1
-		do j=i,m1
-			hess(i,j)=v1((j-1)*j/2+i)
-		end do
-	end do
-
-	do i=2,m1
-		do j=1,i-1
-			hess(i,j)=hess(j,i)
-		end do
-	end do
-
-	
-	ep=10.d-10
-	call dsinvJ(v,m,ep,ier)
-	
-	if (ier.eq.-1) then
-		istop=3
-		
-!AD:
-!		call dsinvj(v1,m1,ep,ier)
-!		if (ier.eq.-1) then
-!             write(*,*)'echec inversion matrice information
-!     & prms fixes'
-!			istop=31
-!		else
-!			DO k=1,m1*(m1+1)/2
-!				v(k)=v1(k)
-!			END DO
-!		end if	
-! fin ajout amadou
-	endif
-
-	
-	ep=10.d-10
-	call deriva(b,m,vnonpen,rl,zero,fctnames)
-	
-	do i=1,m
-		do j=i,m
-			I_hess(i,j)=vnonpen((j-1)*j/2+i)
-		end do
-	end do
-   
-	do i=2,m
-		do j=1,i-1
-			I_hess(i,j)=I_hess(j,i)
-		end do
-	end do
-
-!========================================================
-
-!   H_hess est moins la hessienne inverse sur la vraisemblance penalisee
-	do i=1,m
-		do j=i,m
-			H_hess(i,j)=v((j-1)*j/2+i)
-		end do
-	end do
-!       write(*,*) 'H_hess(16,16) fin marq',H_hess(16,16),m,((j-1)*j/2+i)
-
-	do i=2,m
-		do j=1,i-1
-			H_hess(i,j)=H_hess(j,i)
-		end do
-	end do      
-
- !AD:
-	if (typeof .ne. 0) then
-		do i=1,m*(m+1)/2
-			vvv(i)=v(i)
-		end do
-	end if
-
- 110   continue
-
-       return    
-
-       end subroutine marq98
-
-
-	subroutine deriva(b,m,v,rl,k0,fctnames)
-	use comonmultiv,only:model
-	implicit none
-	
-	integer,intent(in)::m
-	double precision,intent(inout)::rl
-	double precision,dimension(3)::k0
-	double precision,dimension(m),intent(in)::b
-	double precision,dimension((m*(m+3)/2)),intent(out)::v     
-	double precision,dimension(m)::fcith
-	integer ::i0,m1,ll,i,k,j,iun
-	double precision::fctnames,thn,th,z,vl,th2,vaux  
-	external::fctnames
-      	
-	select case(model)
-	case(1)
-		th=1.d-3 !joint	
-	case(2)
-		th=5.d-3 !additive
-	case(3)
-		th=1.d-5 !nested		
-	case(4)
-		th=1.d-5 !shared
-	end select
-	
-	thn=-th
-	th2=th*th
-	z=0.d0
-	i0=0
-	iun =1
-
-	rl=fctnames(b,m,iun,z,iun,z,k0)
-        if(rl.eq.-1.d9) then
-            rl=-1.d9
-            goto 123
-        end if	
-	do i=1,m
-		fcith(i)=fctnames(b,m,i,th,i0,z,k0)
-                if(fcith(i).eq.-1.d9) then
-                    rl=-1.d9
-                    goto 123
-                end if
-	end do
-
-	k=0
-	m1=m*(m+1)/2
-	ll=m1
-	
-	do i=1,m
-		ll=ll+1
-		vaux=fctnames(b,m,i,thn,i0,z,k0)
-                if(vaux.eq.-1.d9) then
-                    rl=-1.d9
-                    goto 123
-                end if	
-		vl=(fcith(i)-vaux)/(2.d0*th)
-		v(ll)=vl
-		do j=1,i
-			k=k+1
-			v(k)=-(fctnames(b,m,i,th,j,th,k0)-fcith(j)-fcith(i)+rl)/th2
-		end do
-	end do
-      
-123   continue	
-	return
-	
-	end subroutine deriva
-
-
-      subroutine searpas(vw,step,b,bh,m,delta,fim,k0,fctnames)
-!
-!  MINIMISATION UNIDIMENSIONNELLE
-!
-      implicit none
-       
-      integer,intent(in)::m      
-      double precision,dimension(m),intent(in)::b
-      double precision,intent(inout)::vw
-      double precision,dimension(m),intent(inout)::bh,delta      
-      double precision,intent(inout)::fim,step   
-      double precision::vlw,vlw1,vlw2,vlw3,vm,fi1,fi2,fi3    
-      double precision,dimension(3)::k0
-      double precision::fctnames
-      external::fctnames
-      integer::i 
-
-       vlw1=dlog(vw)
-       vlw2=vlw1+step
-       call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
-       call valfpa(vlw2,fi2,b,bh,m,delta,k0,fctnames)       
-
-       if(fi2.ge.fi1) then
-	  vlw3=vlw2
-	  vlw2=vlw1
-	  fi3=fi2
-	  fi2=fi1
-	  step=-step
-
-          vlw1=vlw2+step
-          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)   
-          if(fi1.gt.fi2) goto 50
-       else 
-          vlw=vlw1
-          vlw1=vlw2
-          vlw2=vlw
-          fim=fi1
-          fi1=fi2
-          fi2=fim
-       end if
-
-       do i=1,40
-          vlw3=vlw2
-          vlw2=vlw1
-          fi3=fi2
-          fi2=fi1
-
-          vlw1=vlw2+step
-          call valfpa(vlw1,fi1,b,bh,m,delta,k0,fctnames)
-          if(fi1.gt.fi2) goto 50
-          if(fi1.eq.fi2) then
-             fim=fi2
-             vm=vlw2 
-             goto 100
-          end if
-       end do
-!
-!  PHASE 2 APPROXIMATION PAR QUADRIQUE
-!
-50     continue
-!
-!  CALCUL MINIMUM QUADRIQUE
-!
-      vm=vlw2-step*(fi1-fi3)/(2.d0*(fi1-2.d0*fi2+fi3))   
-      call valfpa(vm,fim,b,bh,m,delta,k0,fctnames)	
-      if(fim.le.fi2) goto 100
-      vm=vlw2
-      fim=fi2
-100   continue
-      vw=dexp(vm)
-      
-      return
-
-      end subroutine searpas
-
-
-	subroutine valfpa(vw,fi,b,bk,m,delta,k0,fctnames)
-	
-	implicit none
-	
-	integer,intent(in)::m  
-	double precision,dimension(m),intent(in)::b,delta  
-	double precision,dimension(m),intent(out)::bk 
-	double precision,intent(out)::fi 
-	double precision::vw,fctnames,z	
-	double precision,dimension(3)::k0
-	integer::i0,i
-	external::fctnames
-	
-	z=0.d0
-	i0=1
-	do i=1,m
-	bk(i)=b(i)+dexp(vw)*delta(i)
-	end do
-	fi=-fctnames(bk,m,i0,z,i0,z,k0)
-	if(fi.eq.-1.D9) then
-		goto 1
-	end if
-1       continue
-	return
-	
-	end subroutine valfpa
+    end do 
+        
+    return
+    end subroutine dmaxt
 
 
 
 
 
 
+    end module optim
 
-
-	end module optim
-
-		
+        
